﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using WaveLib;

namespace WaveTest
{
    public partial class MultipleWaveForm : Form
    {
        // map a wave to a specific state user control dealie
        Dictionary<Guid, WaveInfo> mWaveMap = new Dictionary<Guid, WaveInfo>();
        WaveCollection mWC;

        public MultipleWaveForm()
        {
            InitializeComponent();
        }

        private void MultipleWaveForm_Load(object sender, EventArgs e)
        {
            // find all waves connected to the system
            mWC = new WaveCollection();
            int index = 1;

            try
            {
                mWC.FindAllWaves();
            }
            catch (WaveNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Wave not found error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (WaveException ex)
            {
                MessageBox.Show(ex.Message, "Wave error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Unknown error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

            foreach (Wave wm in mWC)
            {
                // create a new tab
                TabPage tp = new TabPage("Wave " + index);
                tabWaves.TabPages.Add(tp);

                // create a new user control
                WaveInfo wi = new WaveInfo(wm);
                tp.Controls.Add(wi);

                // setup the map from this wave's ID to that control
                mWaveMap[wm.ID] = wi;

                // connect it and set it up as always
                wm.WaveChanged += wm_WaveChanged;

                wm.Connect();
            }
        }

        void wm_WaveChanged(object sender, WaveChangedEventArgs e)
        {
            WaveInfo wi = mWaveMap[((Wave)sender).ID];
            wi.UpdateState(e);
        }

        private void MultipleWaveForm_FormClosing(object sender, FormClosingEventArgs e)
        {
            foreach (Wave wm in mWC)
                wm.Disconnect();
        }


    }
}
